@@ -3,7 +3,8 @@ import overpy
 
 class QueryResult:
     def __init__(self, result: overpy.Result, railway_type: str):
-        """ Class representing the Query Result
+        """
+        Class representing the Query Result
 
         Parameters
         ----------
@@ -11,6 +12,9 @@ class QueryResult:
             Result of the overpy query
         railway_type: str
             Railway type that was used for this query
+        Returns
+        -------
+        None
         """
         self.railway_type = railway_type
         self.result: overpy.Result = result
@@ -21,7 +25,17 @@ class QueryResult:
 
     @result.setter
     def result(self, value: overpy.Result):
-        # Assign ways to nodes
+        """
+        Assigns ways to nodes
+        Parameters
+        ----------
+        value: overpy.Result
+            The result whose nodes are assigned ways to.
+
+        Returns
+        -------
+        None
+        """
         if value:
             for way in value.ways:
                 for node in way.nodes:
