@@ -23,10 +23,18 @@ class ComfortProcessor(PostProcessor):
 
         Parameters
         ----------
-        campaign
-        f_s
-        v_thres
-        method
+        campaign: pyridy.Campaign
+            An object used to import and evaluate several measurements made using Ridy.
+        f_s: int
+            Sample rate, as ordinary frequency [Hz]. Defaults to 200.
+        v_thres: float
+            Threshold velocity. Defaults to 0.
+        method: str
+            Standard to process acceleration data. Defaults to the EN 12299 standard.
+
+        Raises
+        -------
+        ValueError: Raised if method is not supported ("EN1299" or "Wz")
         """
         super(ComfortProcessor, self).__init__(campaign)
         self.f_s = f_s
@@ -39,23 +47,37 @@ class ComfortProcessor(PostProcessor):
             raise NotImplementedError('The Wz method has not been implemented yet.')
 
     @staticmethod
-    def calc_comfort_en12999(acc_x: np.ndarray, acc_y: np.ndarray, acc_z: np.ndarray, f_s: int = 200):
-        """ Static method that works purely with numpy arrays for optional use on non campaign like data
+    def calc_comfort_en12999(acc_x: np.ndarray, acc_y: np.ndarray, acc_z: np.ndarray, f_s: int):
+        """
+        Static method that works purely with numpy arrays for optional use on non campaign like data
 
         Parameters
         ----------
-        acc_x
-        acc_y
-        acc_z
-        f_s
+        acc_x: np.ndarray
+            Acceleration according to x-axis.
+        acc_y: np.ndarray
+            Acceleration according to y-axis.
+        acc_z: np.ndarray
+            Acceleration according to z-axis.
+        f_s: int
+            Sample rate, as ordinary frequency [Hz]. Defaults to 200.
 
         Returns
         -------
+        n_mv: ndarray
+        t: ndarray
+            Array of segment times
+        cc_x: ndarray
+            Comfort index according to x-axis
+        cc_y: ndarray
+            Comfort index according to y-axis
+        cc_z: ndarray
+            Comfort index according to z-axis
 
         """
         # The evaluation assumes the phone is laying on the floor pointing in the direction of travel
-        Wb = ComfortProcessor.Wb(f_s)
-        Wd = ComfortProcessor.Wd(f_s)
+        Wb = ComfortProcessor.Wb(f_s) # weighting factor: Vertical Whole-Body Vibration, Z Axis
+        Wd = ComfortProcessor.Wd(f_s) # Horizontal Whole-Body Vibration, X or Y Axis
 
         a_x_wd = signal.lfilter(Wd[0], Wd[1], acc_x)  # Adjusting to vehicle coordinate system
         a_y_wd = signal.lfilter(Wd[0], Wd[1], acc_y)
@@ -78,6 +100,19 @@ class ComfortProcessor(PostProcessor):
         return n_mv, t, cc_x, cc_y, cc_z
 
     def create_map(self, use_file_color=False) -> Map:
+        """
+        Creates a pyridy.widgets Map showing the GPS tracks of measurement files and adds the nodes to the map.
+
+        Parameters
+        ----------
+        use_file_color: bool
+            Defaults to False.
+
+        Returns
+        -------
+        m: pyridy.widgets Map
+            The created map.
+        """
         m = self.campaign.create_map(show_gps_tracks=True, show_railway_elements=False)
         m.add_results_from_campaign(self.campaign, use_file_color=use_file_color)
         return m
@@ -85,7 +120,7 @@ class ComfortProcessor(PostProcessor):
     def execute(self):
         """ Executes the Comfort Processor on the given axes
 
-        Parameters
+        Returns
         ----------
         """
 
@@ -205,6 +240,19 @@ class ComfortProcessor(PostProcessor):
     # Filter functions
     @staticmethod
     def Wb(f_s: int):
+        """
+        Calculates the frequency weighting filter Wb in the vertical direction
+
+        Parameters
+        ----------
+        f_s: int
+            sample rate
+
+        Returns
+        -------
+        tuple(np.ndarray, np.ndarray)
+            Numerator and denominator of the weighting factor
+        """
 
         f1, f2 = 0.4, 100  # [Hz]
         f3, f4 = 16, 16  # [Hz]
@@ -237,6 +285,19 @@ class ComfortProcessor(PostProcessor):
 
     @staticmethod
     def Wc(f_s: int):
+        """
+        Calculates the weighting filter Wc in Horizontal seated direction
+
+        Parameters
+        ----------
+        f_s: int
+            sample rate
+
+        Returns
+        -------
+        tuple(np.ndarray, np.ndarray)
+            Numerator and denominator of the weighting factor
+        """
 
         f1, f2 = 0.4, 100  # [Hz]
         f3, f4 = 8, 8  # [Hz]
@@ -262,6 +323,19 @@ class ComfortProcessor(PostProcessor):
 
     @staticmethod
     def Wd(f_s: int):
+        """
+        Calculates the frequency weighting filter Wb in both longitudinal and lateral direction
+
+        Parameters
+        ----------
+        f_s: int
+            sample rate
+
+        Returns
+        -------
+        tuple(np.ndarray, np.ndarray)
+            Numerator and denominator of the weighting factor
+        """
 
         f1, f2 = 0.4, 100  # [Hz]
         f3, f4 = 2, 2  # [Hz]
@@ -287,6 +361,19 @@ class ComfortProcessor(PostProcessor):
 
     @staticmethod
     def Wp(f_s: int):
+        """
+        Calculates the frequency weighting filter Wb on the floor level
+
+        Parameters
+        ----------
+        f_s: int
+            sample rate
+
+        Returns
+        -------
+        tuple(np.ndarray, np.ndarray)
+            Numerator and denominator of the weighting factor
+        """
 
         f1 = 0  # [Hz]
         f2 = 100  # [Hz]
